
//structure          -- The mine structure.
//weapon             -- The weapon on the mine structure that is fired during explosion. Optional.
//fizzleWep          -- weapon that firea above mine for mine sweeper cyborgs. Optional.
//blipWep            -- weapon that fires above mine for non mine sweeper cyborgs. Optional.
//explodeDist        -- Distance a unit must get for the mine to explode.
//alertDist          -- Distance a unit must get for the mine fizzle/blip weapon to show above the mine.
//healthWarnLevel    -- How much percentage of health the mine must have to show the fizzle/blip alert weapons.
//blastHealthRemoval -- How much percentage of current unit health to take off the unit in the explodeDist range (0.01 - 0.99). Optional.

//Anything optional can be made undefined (fizzleWep: undefined).
const MINES = [
	{
		structure: "ContaMine1", weapon: "WepMine1", fizzleWep: "ZNULLMINE", blipWep: "ZNULLMINE",
		explodeDist: 5, alertDist: 6, healthWarnLevel: 40, blastHealthRemoval: 0.8
	},
	{
		structure: "ContaMine2", weapon: "WepMine2", fizzleWep: "ZNULLMINE", blipWep: "ZNULLMINE",
		explodeDist: 5, alertDist: 6, healthWarnLevel: 40, blastHealthRemoval: 0.8
	},
	{
		structure: "ContaMine3", weapon: "WepMine3", fizzleWep: "ZNULLMINE", blipWep: "ZNULLMINE",
		explodeDist: 5, alertDist: 6, healthWarnLevel: 40, blastHealthRemoval: 0.8
	},
	{
		structure: "ContaMine4", weapon: "WepMine4", fizzleWep: "ZNULLMINE", blipWep: "ZNULLMINE",
		explodeDist: 5, alertDist: 6, healthWarnLevel: 40, blastHealthRemoval: 0.8
	},
	{
		structure: "ContaMine5", weapon: "WepMine5", fizzleWep: "ZNULLMINE", blipWep: "ZNULLMINE",
		explodeDist: 5, alertDist: 6, healthWarnLevel: 40, blastHealthRemoval: 0.8
	},
	{
		structure: "ContaMine6", weapon: "WepMine6", fizzleWep: "ZNULLMINE", blipWep: "ZNULLMINE",
		explodeDist: 5, alertDist: 6, healthWarnLevel: 40, blastHealthRemoval: 0.8
	},
	{
		structure: "ContaMine7", weapon: "WepMine7", fizzleWep: "ZNULLMINE", blipWep: "ZNULLMINE",
		explodeDist: 5, alertDist: 6, healthWarnLevel: 40, blastHealthRemoval: 0.8
	},
	{
		structure: "ContaMine8", weapon: "WepMine8", fizzleWep: "ZNULLMINE", blipWep: "ZNULLMINE",
		explodeDist: 5, alertDist: 6, healthWarnLevel: 40, blastHealthRemoval: 0.8
	},
];

const MINE_CYBORGS = [
	{body: "CyborgLightBody-Miner", propulsion: "CyborgLegs", weapon: "CyborgSpade-Miner"},
];

function isMinerComponent(thing)
{
	for (var t = 0; t < MINE_CYBORGS.length; ++t)
	{
		var obj = MINE_CYBORGS[t];
		if (obj.body === thing || obj.weapon === thing)
		{
			return true;
		}
	}
	return false;
}

function checkMines()
{
	for (var i = 0; i < maxPlayers; ++i)
	{
		for (var s = 0, mineLen = MINES.length; s < mineLen; ++s)
		{
			var mineData = MINES[s];
			var mines = enumStruct(i, mineData.structure);

			for (var j = 0, len = mines.length; j < len; ++j)
			{
				var mineExists = true;
				var mine = mines[j];

				if (mine.status !== BUILT)
				{
					continue;
				}

				var nearbyObjects = enumRange(mine.x, mine.y, mineData.alertDist, ALL_PLAYERS, false);

				for (var c = 0, len2 = nearbyObjects.length; c < len2; ++c)
				{
					var what = nearbyObjects[c];

					if (what.type !== DROID)
					{
						continue;
					}
					if (isVTOL(what))
					{
						continue;
					}

					//Allow some form of alert to display if the mine is healthy
					if (mineExists === true && mine.health > mineData.healthWarnLevel)
					{
						//Mine sweepers can see every mine
						if (isMinerComponent(what.body))
						{
							if (mineData.fizzleWep)
							{
								fireWeaponAtLoc(mine.x, mine.y, mineData.fizzleWep);
							}
							continue;
						}
						//Non mine sweepers can see mines that they own at close range
						else if (what.player === mine.player && distBetweenTwoPoints(mine.x, mine.y, what.x, what.y) > mineData.explodeDist)
						{
							if (mineData.blipWep)
							{
								fireWeaponAtLoc(mine.x, mine.y, mineData.blipWep);
							}
							continue;
						}
					}

					//Automatically knock health to some percentage of what they got now.
					if (what.health > 2)
					{
						if (mineData.blastHealthRemoval)
						{
							setHealth(what, Math.floor(what.health * mineData.blastHealthRemoval));
						}
					}
					else
					{
						//Careful, the unit does not exist after this removeObject().
						removeObject(what, true);
					}

					//Explode the mine and remove it.
					if (mineExists === true)
					{
						if (mineData.weapon)
						{
							fireWeaponAtLoc(mine.x, mine.y, mineData.weapon);
						}
						removeObject(mine, true);
						mineExists = false;
					}
				}
			}
		}
	}
}
